Localization

Struct Localization 

pub struct Localization(/* private fields */);
Table 143 — Localization of value 16 bit bitfield parameter definition

Repr: u16

FieldSize (bits)note
sign10 means comparison without sign.
1 means comparison with sign.
length5The value 0x00 shall be used to compare all 4 bytes.
All other values shall set the size in bits.
With 5 bits, the maximal size of a length is 31 bits.
offset10Offset on the positive response message from where to
extract the data identifier value.

Implementations

Source

impl Localization

pub const fn new() -> Self

Creates a new default initialized bitfield.

pub const fn from_bits(bits: u16) -> Self

Convert from bits.

pub const fn into_bits(self) -> u16

Convert into bits.

Source

impl Localization

pub const fn is_sign(&self) -> bool

pub fn sign_set(&mut self, value: bool) -> &mut Self

pub const fn length_value(&self) -> u8

pub fn length_set(&mut self, value: u8) -> &mut Self

pub const fn offset_value(&self) -> u16

pub fn offset_set(&mut self, value: u16) -> &mut Self