pub struct Localization(/* private fields */);Expand description
Table 143 — Localization of value 16 bit bitfield parameter definition
Repr: u16
| Field | Size (bits) | note |
|---|---|---|
| sign | 1 | 0 means comparison without sign. |
| 1 means comparison with sign. | ||
| length | 5 | The value 0x00 shall be used to compare all 4 bytes. |
| All other values shall set the size in bits. | ||
| With 5 bits, the maximal size of a length is 31 bits. | ||
| offset | 10 | Offset on the positive response message from where to |
| extract the data identifier value. |
Implementations
Sourceimpl Localization
impl Localization
Sourceimpl Localization
impl Localization
pub const fn is_sign(&self) -> bool
pub fn sign_set(&mut self, value: bool) -> &mut Self
pub const fn length_value(&self) -> u8
pub fn length_set(&mut self, value: u8) -> &mut Self
pub const fn offset_value(&self) -> u16
pub fn offset_set(&mut self, value: u16) -> &mut Self